"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const nodeCommands = __importStar(require("../../../src/node-commands"));
const guiCommands = __importStar(require("../../../src/gui-commands"));
const dotenv_1 = __importDefault(require("dotenv"));
// Mock the commander package
jest.mock('commander', () => {
    const mockCommand = {
        name: jest.fn().mockReturnThis(),
        description: jest.fn().mockReturnThis(),
        version: jest.fn().mockReturnThis(),
        parse: jest.fn(),
    };
    return {
        Command: jest.fn().mockImplementation(() => mockCommand),
    };
});
// Mock the command modules
jest.mock('../../../src/node-commands', () => ({
    registerNodeCommands: jest.fn(),
}));
jest.mock('../../../src/gui-commands', () => ({
    registerGuiCommands: jest.fn(),
}));
// Mock dotenv
jest.mock('dotenv', () => ({
    config: jest.fn(),
}));
// Mock path
jest.mock('path', () => ({
    join: jest.fn().mockImplementation((...args) => args.join('/')),
}));
// Mock process.chdir
const originalChdir = process.chdir;
beforeAll(() => {
    process.chdir = jest.fn();
});
afterAll(() => {
    process.chdir = originalChdir;
});
describe('CLI Entry Point', () => {
    beforeEach(() => {
        jest.clearAllMocks();
        // Mock package.json
        jest.mock('../../../package.json', () => ({
            version: '1.2.1',
        }), { virtual: true });
    });
    afterEach(() => {
        jest.resetModules();
    });
    it('should initialize the CLI correctly', () => {
        // Import the index file
        jest.isolateModules(() => {
            // This will execute the index.ts code
            require('../../../src/index');
        });
        // Verify dotenv config was called
        expect(dotenv_1.default.config).toHaveBeenCalled();
        // Verify process.chdir was called
        expect(process.chdir).toHaveBeenCalled();
        // Verify Command was instantiated
        expect(commander_1.Command).toHaveBeenCalled();
        const program = new commander_1.Command();
        // Verify program configuration
        expect(program.name).toHaveBeenCalledWith('operator-cli');
        expect(program.description).toHaveBeenCalledWith('CLI part of the operator dashboard');
        expect(program.version).toHaveBeenCalledWith('1.2.1');
        // Verify command registration
        expect(nodeCommands.registerNodeCommands).toHaveBeenCalledWith(program);
        expect(guiCommands.registerGuiCommands).toHaveBeenCalledWith(program);
        // Verify program.parse was called
        expect(program.parse).toHaveBeenCalled();
    });
});
//# sourceMappingURL=index.test.js.map