"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const winston_1 = __importDefault(require("winston"));
const logger_1 = __importDefault(require("../../../src/utils/logger"));
// Mock winston
jest.mock('winston', () => {
    const mockFormat = {
        json: jest.fn().mockReturnValue('json-format'),
    };
    const mockTransport = jest.fn();
    const mockLogger = {
        level: '',
        format: '',
        defaultMeta: {},
        transports: [],
    };
    return {
        format: mockFormat,
        createLogger: jest.fn().mockImplementation((config) => {
            mockLogger.level = config.level;
            mockLogger.format = config.format;
            mockLogger.defaultMeta = config.defaultMeta;
            mockLogger.transports = config.transports || [];
            return mockLogger;
        }),
        transports: {
            File: mockTransport.mockReturnValue({ filename: 'mocked-file' }),
        },
    };
});
// Mock path
jest.mock('path', () => ({
    join: jest.fn().mockImplementation((...args) => args.join('/')),
}));
describe('logger', () => {
    it('should be configured correctly', () => {
        // Verify logger configuration
        expect(winston_1.default.createLogger).toHaveBeenCalledWith({
            level: 'info',
            format: 'json-format',
            defaultMeta: { service: 'node' },
            transports: expect.any(Array),
        });
        // Verify winston format
        expect(winston_1.default.format.json).toHaveBeenCalled();
        // Verify File transports were created
        expect(winston_1.default.transports.File).toHaveBeenCalledTimes(2);
        // Verify File transports were created with correct paths
        expect(winston_1.default.transports.File).toHaveBeenCalledWith({
            filename: expect.stringContaining('logs/error.log'),
            level: 'error',
        });
        expect(winston_1.default.transports.File).toHaveBeenCalledWith({
            filename: expect.stringContaining('logs/combined.log'),
        });
    });
    it('should export a winston logger instance', () => {
        expect(logger_1.default).toBeDefined();
    });
});
//# sourceMappingURL=logger.test.js.map